# logiclayer-merge

Allows to merge the results of other LogicLayer modules in a single response.

<a href="https://pypi.org/project/logiclayer-merge/"><img src="https://flat.badgen.net/pypi/v/logiclayer-merge" /></a>
<a href="https://github.com/Datawheel/logiclayer-merge/"><img src="https://flat.badgen.net/static/github/repo/green?icon=github" /></a>
<a href="https://github.com/Datawheel/logiclayer-merge/issues"><img src="https://flat.badgen.net/static/github/issues/blue?icon=github" /></a>

## Usage

Check the directions in the [PACKAGE.md file](./PACKAGE.md).

## Development

This project is managed using [uv](https://docs.astral.sh/uv/). After cloning the repo, create a virtual environment and install the required packages using

```bash
$ uv sync
```

## Docker Compose

- Build: `docker compose build`
- Run: `docker compose up`

---

&copy; Datawheel, LLC.
